
<table
	style="table-layout: fixed; vertical-align: top; min-width: 320px; border-spacing: 0; border-collapse: collapse; mso-table-lspace: 0pt; mso-table-rspace: 0pt; background-color: #ffffff; width: 100%; user-select: none;"
	width="100%" cellspacing="0" cellpadding="0" bgcolor="#FFFFFF">
	<tbody>
		<tr style="vertical-align: top;" valign="top">
			<td style="word-break: break-word; vertical-align: top;" valign="top">
				<table border="0" width="100%" cellspacing="0" cellpadding="0">
					<tbody>
						<tr>
							<td style="background-color: #ffffff;" align="center">
								<div style="background-color: #ff4f5a;">
									<div
										style="min-width: 320px; max-width: 600px; overflow-wrap: break-word; word-wrap: break-word; word-break: break-word; margin: 0 auto; background-color: transparent;">
										<div
											style="border-collapse: collapse; display: table; width: 100%; background-color: transparent;">
											<table style="background-color: #132437;" border="0" width="100%"
												cellspacing="0" cellpadding="0">
												<tbody>
													<tr>
														<td align="center">
															<table style="width: 600px;" border="0" cellspacing="0"
																cellpadding="0">
																<tbody>
																	<tr style="background-color: transparent;">
																		<td style="background-color: #c7c7c7; width: 600px; border: 0px solid transparent;"
																			align="center" valign="top" width="600">
																			<table border="0" width="100%"
																				cellspacing="0" cellpadding="0">
																				<tbody>
																					<tr>
																						<td style="padding: 0px;">
																							<div
																								style="min-width: 320px; max-width: 600px; display: table-cell; vertical-align: top; width: 600px;">
																								<div
																									style="width: 100% !important;">
																									<div
																										style="border: 0px solid transparent; padding: 0px;">
																										<div style="padding-right: 30px; padding-left: 30px;"
																											align="center">
																											<table
																												border="0"
																												width="100%"
																												cellspacing="0"
																												cellpadding="0">
																												<tbody>
																													<tr
																														style="line-height: 0px;">
																														<td style="padding-right: 30px; padding-left: 30px;"
																															align="center">
																															<div
																																style="font-size: 1px; line-height: 35px;">
																																 
																															</div>
																															<img style="text-decoration: none; -ms-interpolation-mode: bicubic; height: auto; border: 0; width: 100%; max-width: 150px; display: block;"
																																title="souqdar-logo"
																																src="https://blogger.googleusercontent.com/img/a/AVvXsEieciapKxLOE19Y6t6nOt-_A90xyMCZ_FCvoELjgwvg7CH-c6290yt6qRZYNQ1YhxOpJNbwxwqmi6daFJVBduUmHNSjqtFlQKV8FQWfjqJzNifphvz16R4NKe74XvemQfYZMfc36i0RcIkgwtlxgmuPdzc9fy3I3CDaOJdA1S8oiX-CX8GTm7SLUurTWw=s4191"
																																alt="Books Plus"
																																width="150"
																																align="center"
																																border="0" />
																															<div
																																style="font-size: 1px; line-height: 35px;">
																																 
																															</div>
																														</td>
																													</tr>
																												</tbody>
																											</table>
																										</div>
																									</div>
																								</div>
																							</div>
																						</td>
																					</tr>
																				</tbody>
																			</table>
																		</td>
																	</tr>
																</tbody>
															</table>
														</td>
													</tr>
												</tbody>
											</table>
										</div>
									</div>
								</div>
								<div style="background-color: #ff4f5a;">
									<div
										style="min-width: 320px; max-width: 600px; overflow-wrap: break-word; word-wrap: break-word; word-break: break-word; margin: 0 auto; background-color: #ffffff;">
										<div
											style="border-collapse: collapse; display: table; width: 100%; background-color: #ffffff;">
											<table style="background-color: #132437;" border="0" width="100%"
												cellspacing="0" cellpadding="0">
												<tbody>
													<tr>
														<td align="center">
															<table style="width: 600px;" border="0" cellspacing="0"
																cellpadding="0">
																<tbody>
																	<tr style="background-color: #ffffff;">
																		<td style="background-color: #ffffff; width: 600px; border: 0px solid transparent;"
																			align="center" valign="top" width="600">
																			<table border="0" width="100%"
																				cellspacing="0" cellpadding="0">
																				<tbody>
																					<tr>
																						<td
																							style="padding: 0px 0px 10px 0px;">
																							<div
																								style="min-width: 320px; max-width: 600px; display: table-cell; vertical-align: top; width: 600px;">
																								<div
																									style="width: 100% !important;">
																									<div
																										style="border: 0px solid transparent; padding: 0px 0px 10px 0px;">
																										<div style="padding-right: 20px; padding-left: 20px;"
																											align="center">
																											
																										</div>
																									</div>
																								</div>
																							</div>
																						</td>
																					</tr>
																				</tbody>
																			</table>
																		</td>
																	</tr>
																</tbody>
															</table>
														</td>
													</tr>
												</tbody>
											</table>
										</div>
									</div>
								</div>
								<div style="background-color: #ff4f5a;">
									<div
										style="min-width: 320px; max-width: 600px; overflow-wrap: break-word; word-wrap: break-word; word-break: break-word; margin: 0 auto; background-color: #ffffff;">
										<div
											style="border-collapse: collapse; display: table; width: 100%; background-color: #ffffff;">
											<table background-color: #ff7d14;" border="0" width="100%" cellspacing="0"
												cellpadding="0">
												<tbody>
													<tr>
														<td align="center">
															<table style="width: 600px;" border="0" cellspacing="0"
																cellpadding="0">
																<tbody>
																	<tr style="background-color: #ffffff;">
																		<td style="background-color: #ffffff; width: 600px; border: 0px solid transparent;"
																			align="center" valign="top" width="600">
																			<table border="0" width="100%"
																				cellspacing="0" cellpadding="0">
																				<tbody>
																					<tr>
																						<td style="padding: 0px;">
																							<div
																								style="min-width: 320px; max-width: 600px; display: table-cell; vertical-align: top; width: 600px;">
																								<div
																									style="width: 100% !important;">
																									<div
																										style="border: 0px solid transparent; padding: 0px;">
																										<table
																											style="text-align: center; table-layout: fixed; vertical-align: top; border-spacing: 0; border-collapse: collapse; mso-table-lspace: 0pt; mso-table-rspace: 0pt;"
																											width="100%"
																											cellspacing="0"
																											cellpadding="0">
																											<tbody>
																												<tr style="vertical-align: top;"
																													valign="top">
																													<td style="word-break: break-word; vertical-align: top; text-align: center; width: 100%; padding: 25px 0px 5px 0px;"
																														align="center"
																														valign="top"
																														width="100%">
																														<h1
																															style="color: #555555; direction: ltr; font-family: Arial, Helvetica Neue, Helvetica, sans-serif; font-size: 30px; font-weight: normal; letter-spacing: normal; line-height: 120%; text-align: center; margin-top: 0; margin-bottom: 0;">
																															<strong>
																															
																															Welcome to {{ domain }}
																															
																															</strong>
																														</h1>
																													</td>
																												</tr>
																											</tbody>
																										</table>
																										<table
																											border="0"
																											width="100%"
																											cellspacing="0"
																											cellpadding="0">
																											<tbody>
																												<tr>
																													<td
																														style="font-family: Arial, sans-serif;">
																														<div
																															style="color: #737487; font-family: Arial, Helvetica Neue, Helvetica, sans-serif; line-height: 1.8; padding: 20px 30px 20px 30px;">
																															<div
																																style="font-size: 14px; line-height: 1.8; color: #737487; font-family: Arial, Helvetica Neue, Helvetica, sans-serif; mso-line-height-alt: 25px;">
																																<p
																																	style="margin: 0; font-size: 18px; line-height: 1.8; word-break: break-word; text-align: center; mso-line-height-alt: 32px; margin-top: 0; margin-bottom: 0;">
										<span style="font-size: 18px;"> Hello <strong>{{username}}</strong> you are just one step ahead to registered your 
											account. Just enter the below code number to confirm your email and than
										You can sign into your account.</span>
																																</p>
																															</div>
																														</div>
																													</td>
																												</tr>
																											</tbody>
																										</table>
																										<div
																											align="center">
																											<table
																												style="border-spacing: 0; border-collapse: collapse; mso-table-lspace: 0pt; mso-table-rspace: 0pt;"
																												border="0"
																												width="100%"
																												cellspacing="0"
																												cellpadding="0">
																												<tbody>
																													<tr>
																														<td style="padding: 20px 15px 50px 15px;"
																															align="center">
																															<center
																																style="color: #ffffff; font-family: Arial, sans-serif; font-size: 16px;">
																																<a style="-webkit-text-size-adjust: none; text-decoration: none; display: inline-block; color: #ffffff; background-color: #ff4f5a; border-radius: 4px; -webkit-border-radius: 4px; -moz-border-radius: 4px; width: auto; padding-top: 10px; padding-bottom: 10px; font-family: Arial, Helvetica Neue, Helvetica, sans-serif; text-align: center; mso-border-alt: none; word-break: keep-all;"
																																
																																	target="_blank"><span
																																		style="padding-left: 60px; padding-right: 60px; font-size: 16px; display: inline-block; letter-spacing: undefined;"><span
																																			style="font-size: 16px; line-height: 2; word-break: break-word; mso-line-height-alt: 32px;"><strong>{{ code }}
																													</strong></span></span></a>
																															</center>
																														</td>
																													</tr>
																												</tbody>
																											</table>
																										</div>
																										<div style="padding-right: 0px; padding-left: 0px;"
																											align="center">
																											
																										</div>
																									</div>
																								</div>
																							</div>
																						</td>
																					</tr>
																				</tbody>
																			</table>
																		</td>
																	</tr>
																</tbody>
															</table>
														</td>
													</tr>
												</tbody>
											</table>
										</div>
									</div>
								</div>
								<div style="background-color: #333;">
									<div
										style="min-width: 320px; max-width: 600px; overflow-wrap: break-word; word-wrap: break-word; word-break: break-word; margin: 0 auto; background-color: #ffffff;">
										<div
											style="border-collapse: collapse; display: table; width: 100%; background-color: #ffffff;">
											<table style="background-color: #ff7d14;" border="0" width="100%"
												cellspacing="0" cellpadding="0">
												<tbody>
													<tr>
														<td align="center">
															<table style="width: 600px;" border="0" cellspacing="0"
																cellpadding="0">
																<tbody>
																	<tr style="background-color: #ffffff;">
																		<td style="background-color: #ffffff; width: 300px; border: 0px solid transparent;"
																			align="center" valign="top" width="300">
																			<table border="0" width="100%"
																				cellspacing="0" cellpadding="0">
																				<tbody>
																					<tr>
																						<td style="padding: 0px;">
																							<div
																								style="display: table-cell; vertical-align: top; max-width: 320px; min-width: 300px; width: 300px;">
																								<div
																									style="width: 100% !important;">
																									<div
																										style="border: 0px solid transparent; padding: 0px;">
																										<div style="padding-right: 0px; padding-left: 0px;"
																											align="center">
																											
																										</div>
																									</div>
																								</div>
																							</div>
																						</td>
																					</tr>
																				</tbody>
																			</table>
																		</td>
																		<td style="background-color: #ffffff; width: 300px; border: 0px solid transparent;"
																			align="center" valign="top" width="300">
																			<table border="0" width="100%"
																				cellspacing="0" cellpadding="0">
																				<tbody>
																					
																				</tbody>
																			</table>
																		</td>
																	</tr>
																</tbody>
															</table>
														</td>
													</tr>
												</tbody>
											</table>
										</div>
									</div>
								</div>
								<div style="background-color: #333;">
									<div
										style="min-width: 320px; max-width: 600px; overflow-wrap: break-word; word-wrap: break-word; word-break: break-word; margin: 0 auto; background-color: #ffffff;">
										<div
											style="border-collapse: collapse; display: table; width: 100%; background-color: #ffffff;">
											<table style="border: 0; width: 100%;" cellspacing="0" cellpadding="0">
												<tbody>
													<tr>
														<td align="center">
															<table style="width: 600px;" border="0" cellspacing="0"
																cellpadding="0">
																<tbody>
																	<tr style="background-color: #ffffff;">
																		<td style="background-color: #ffffff; width: 600px; border: 0px solid transparent;"
																			align="center" valign="top" width="600">
																			<table border="0" width="100%"
																				cellspacing="0" cellpadding="0">
																				<tbody>
																					<tr>
																						<td style="padding: 0px;">
																							<div
																								style="min-width: 320px; max-width: 600px; display: table-cell; vertical-align: top; width: 600px;">
																								<div
																									style="width: 100% !important;">
																									<div
																										style="border: 0px solid transparent; padding: 0px;">

																										<table
																											border="0"
																											width="100%"
																											cellspacing="0"
																											cellpadding="0">
																											<tbody>
																												<tr>
																													<td
																														style="font-family: Arial, sans-serif;">
																														<div
																															style="color: #737487; font-family: Arial, Helvetica Neue, Helvetica, sans-serif; line-height: 1.8; padding: 20px 30px 20px 30px;">
																															<div
																																style="font-size: 14px; line-height: 1.8; color: #737487; font-family: Arial, Helvetica Neue, Helvetica, sans-serif; mso-line-height-alt: 25px;">
																																<p
																																	style="margin: 0; font-size: 18px; line-height: 1.8; word-break: break-word; text-align: center; mso-line-height-alt: 32px; margin-top: 0; margin-bottom: 0;">
																																	<span
																																		style="font-size: 18px;">
																																		
																																		Thanks for verify your email address.
																																		
																																		</span>
																																</p>
																															</div>
																														</div>
																													</td>
																												</tr>
																											</tbody>
																										</table>
																										<div style="padding-right: 0px; padding-left: 0px;"
																											align="center">
																											
																										</div>
																										
																										
																									</div>
																								</div>
																							</div>
																						</td>
																					</tr>
																				</tbody>
																			</table>
																		</td>
																	</tr>
																</tbody>
															</table>
														</td>
													</tr>
												</tbody>
											</table>
										</div>
									</div>
								</div>
								<div style="background-color: #333;">
									<div
										style="min-width: 320px; max-width: 600px; overflow-wrap: break-word; word-wrap: break-word; word-break: break-word; margin: 0 auto; background-color: transparent;">
										<div
											style="border-collapse: collapse; display: table; width: 100%; background-color: transparent;">
											<table style="background-color: #ff4f5a;" border="0" width="100%"
												cellspacing="0" cellpadding="0">
												<tbody>
													<tr>
														<td align="center">
															<table style="width: 600px;" border="0" cellspacing="0"
																cellpadding="0">
																<tbody>
																	<tr style="background-color: transparent;">
																		<td style="background-color: transparent; width: 600px; border: 0px solid transparent;"
																			align="center" valign="top" width="600">
																			<table border="0" width="100%"
																				cellspacing="0" cellpadding="0">
																				<tbody>
																					<tr>
																						<td style="padding: 0px;">
																							<div
																								style="min-width: 320px; max-width: 600px; display: table-cell; vertical-align: top; width: 600px;">
																								<div
																									style="width: 100% !important;">
																									<div
																										style="border: 0px solid transparent; padding: 0px;">
																										<table
																											border="0"
																											width="100%"
																											cellspacing="0"
																											cellpadding="0">
																											<tbody>
																												<tr>
																													<td
																														style="font-family: Arial, sans-serif; padding: 30px 5px 5px 5px;">
																														<div
																															style="color: #262b30; font-family: Arial, Helvetica Neue, Helvetica, sans-serif; line-height: 1.2; padding: 30px 5px 5px 5px;">
																															<div
																																style="line-height: 1.2; font-size: 12px; font-family: Arial, Helvetica Neue, Helvetica, sans-serif; color: #262b30; mso-line-height-alt: 14px;">
																																<p
																																	style="margin: 0; font-size: 12px; line-height: 1.2; word-break: break-word; text-align: center; mso-line-height-alt: 14px; margin-top: 0; margin-bottom: 0;">
																																	<span
																																		style="font-size: 12px;">&copy;
																																		2019
																																		CleveRange
																																		|
																																		Homna, Cumilla, Bangladesh</span>
																																</p>
																															</div>
																														</div>
																													</td>
																												</tr>
																											</tbody>
																										</table>
																										
																									</div>
																								</div>
																							</div>
																						</td>
																					</tr>
																				</tbody>
																			</table>
																		</td>
																	</tr>
																</tbody>
															</table>
														</td>
													</tr>
												</tbody>
											</table>
										</div>
									</div>
								</div>
							</td>
						</tr>
					</tbody>
				</table>
			</td>
		</tr>
	</tbody>
</table>