{% extends 'account_base.html' %}
    {% block account_auth %}

        <div class="column col-lg-8 col-md-12 col-sm-12">
            <h2>Create an account</h2>
            
            <!-- Register Form -->
            <div class="login-form register-form">
                <!--Login Form-->
                <form method="post" action="">
                    <div class="form-group">
                        {% csrf_token %}
                        {{ form }}
                    </div>
                    

                    <div class="form-group">
                                <a href="{% url 'accounts:login' %}" class="psw">Login Here!</a>
                            </div>

                    <div class="form-group text-right">
                        <button class="theme-btn btn-style-one" type="submit" name="submit-form">Register</button>
                    </div>
                </form>      
            </div>
            <!--End Register Form -->
        </div>

{% endblock account_auth %}