# Generated by Django 3.2.8 on 2021-11-13 23:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0003_auto_20211028_0404'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='username',
            field=models.CharField(default='username', max_length=100, unique=True),
            preserve_default=False,
        ),
    ]
