{% extends 'account/base.html' %}
{% block title %} Create an account{% endblock title %}
    {% block account_auth %}

        <div class="column col-lg-8 col-md-12 col-sm-12 align-self-center">
            <h2>Create an account</h2>
            
            <!-- Register Form -->
            <form action="" method="post">
              <div class="form-control">
                {% csrf_token %}
                {{ form }}
              </div>
               

              <div class="form-control">
                <a href="{% url 'accounts:login' %}" class="psw">Login Here!</a>
              </div>

                <div class="form-control text-right">
                    <button class="btn btn-primary" type="submit" name="submit-form">Register</button>
                </div>
            
            </form>
            <!--End Register Form -->
        </div>

{% endblock account_auth %}